@@ -2,7 +2,7 @@
 # Kernel/Modules/AgentTicketZoom.pm - to get a closer view
 # Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentTicketZoom.pm,v 1.144 2011/01/11 23:11:51 mp Exp $
+# $Id: AgentTicketZoom.pm,v 1.145.2.5 2011-12-19 09:24:05 mab Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -20,7 +20,7 @@ use Kernel::System::EmailParser;
 use Kernel::System::SystemAddress;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.144 $) [1];
+$VERSION = qw($Revision: 1.145.2.5 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -342,8 +342,6 @@ sub MaskAgentZoom {
     my %StandardResponses
         = $Self->{QueueObject}->GetStandardResponses( QueueID => $Ticket{QueueID} );
 
-    $Ticket{TicketTimeUnits} = $Self->{TicketObject}->TicketAccountedTimeGet(%Ticket);
-
     # owner info
     my %OwnerInfo = $Self->{UserObject}->GetUserData(
         UserID => $Ticket{OwnerID},
@@ -696,6 +694,15 @@ sub MaskAgentZoom {
         );
     }
 
+    # show total accounted time if feature is active:
+    if ( $Self->{ConfigObject}->Get('Ticket::Frontend::AccountTime') ) {
+        $Ticket{TicketTimeUnits} = $Self->{TicketObject}->TicketAccountedTimeGet(%Ticket);
+        $Self->{LayoutObject}->Block(
+            Name => 'TotalAccountedTime',
+            Data => \%Ticket,
+        );
+    }
+
     # show pending until, if set:
     if ( $Ticket{UntilTime} ) {
         if ( $Ticket{UntilTime} < -1 ) {
@@ -929,6 +936,12 @@ sub MaskAgentZoom {
         );
     }
 
+    # init js
+    $Self->{LayoutObject}->Block(
+        Name => 'TicketZoomInit',
+        Data => {%Param},
+    );
+
     # return output
     return $Self->{LayoutObject}->Output(
         TemplateFile => 'AgentTicketZoom',
@@ -1627,7 +1640,11 @@ sub _ArticleItem {
     }
 
     # show accounted article time
-    if ( $Self->{ConfigObject}->Get('Ticket::ZoomTimeDisplay') ) {
+    if (
+        $Self->{ConfigObject}->Get('Ticket::ZoomTimeDisplay')
+        && $Self->{ConfigObject}->Get('Ticket::Frontend::AccountTime')
+        )
+    {
         my $ArticleTime = $Self->{TicketObject}->ArticleAccountedTimeGet(
             ArticleID => $Article{ArticleID}
         );
@@ -1653,56 +1670,6 @@ sub _ArticleItem {
         );
     }
 
-    # add block for attachments
-    if ( $Article{Atms} && %{ $Article{Atms} } ) {
-        my %AtmIndex = %{ $Article{Atms} };
-        $Self->{LayoutObject}->Block(
-            Name => 'ArticleAttachment',
-            Data => {},
-        );
-
-        my $Config = $Self->{ConfigObject}->Get('Ticket::Frontend::ArticleAttachmentModule');
-        ATTACHMENT:
-        for my $FileID ( sort keys %AtmIndex ) {
-            my %File = %{ $AtmIndex{$FileID} };
-            $Self->{LayoutObject}->Block(
-                Name => 'ArticleAttachmentRow',
-                Data => \%File,
-            );
-
-            # run article attachment modules
-            next ATTACHMENT if ref $Config ne 'HASH';
-            my %Jobs = %{$Config};
-            JOB:
-            for my $Job ( sort keys %Jobs ) {
-
-                # load module
-                if ( !$Self->{MainObject}->Require( $Jobs{$Job}->{Module} ) ) {
-                    return $Self->{LayoutObject}->ErrorScreen();
-                }
-                my $Object = $Jobs{$Job}->{Module}->new(
-                    %{$Self},
-                    TicketID  => $Self->{TicketID},
-                    ArticleID => $Article{ArticleID},
-                );
-
-                # run module
-                my %Data = $Object->Run(
-                    File => {
-                        %File,
-                        FileID => $FileID,
-                    },
-                    Article => \%Article,
-                );
-                next JOB if !%Data;
-                $Self->{LayoutObject}->Block(
-                    Name => $Data{Block} || 'ArticleAttachmentRowLink',
-                    Data => {%Data},
-                );
-            }
-        }
-    }
-
     # run article view modules
     my $Config = $Self->{ConfigObject}->Get('Ticket::Frontend::ArticleViewModule');
     if ( ref $Config eq 'HASH' ) {
@@ -1746,6 +1713,74 @@ sub _ArticleItem {
         }
     }
 
+    %Article = $Self->{TicketObject}->ArticleGet( ArticleID => $Article{ArticleID} );
+
+    # get attachment index (without attachments)
+    my %AtmIndex = $Self->{TicketObject}->ArticleAttachmentIndex(
+        ArticleID                  => $Article{ArticleID},
+        StripPlainBodyAsAttachment => $Self->{StripPlainBodyAsAttachment},
+        Article                    => \%Article,
+        UserID                     => $Self->{UserID},
+    );
+    $Article{Atms} = \%AtmIndex;
+
+    # add block for attachments
+    if ( $Article{Atms} && %{ $Article{Atms} } ) {
+        my %AtmIndex = %{ $Article{Atms} };
+        $Self->{LayoutObject}->Block(
+            Name => 'ArticleAttachment',
+            Data => {},
+        );
+
+        my $Config = $Self->{ConfigObject}->Get('Ticket::Frontend::ArticleAttachmentModule');
+        ATTACHMENT:
+        for my $FileID ( sort keys %AtmIndex ) {
+            my %File = %{ $AtmIndex{$FileID} };
+            $Self->{LayoutObject}->Block(
+                Name => 'ArticleAttachmentRow',
+                Data => \%File,
+            );
+
+            # run article attachment modules
+            next ATTACHMENT if ref $Config ne 'HASH';
+            my %Jobs = %{$Config};
+            JOB:
+            for my $Job ( sort keys %Jobs ) {
+
+                # load module
+                if ( !$Self->{MainObject}->Require( $Jobs{$Job}->{Module} ) ) {
+                    return $Self->{LayoutObject}->ErrorScreen();
+                }
+                my $Object = $Jobs{$Job}->{Module}->new(
+                    %{$Self},
+                    TicketID  => $Self->{TicketID},
+                    ArticleID => $Article{ArticleID},
+                );
+
+                # run module
+                my %Data = $Object->Run(
+                    File => {
+                        %File,
+                        FileID => $FileID,
+                    },
+                    Article => \%Article,
+                );
+
+                # check for the display of the filesize
+                if ( $Job eq '2-HTML-Viewer' && !%Data ) {
+                    $Data{DataFileSize} = ", " . $File{Filesize};
+                }
+                elsif ( $Job eq '2-HTML-Viewer' && %Data ) {
+                    $Data{DataFileSize} = ", " . $Data{Filesize};
+                }
+                $Self->{LayoutObject}->Block(
+                    Name => $Data{Block} || 'ArticleAttachmentRowLink',
+                    Data => {%Data},
+                );
+            }
+        }
+    }
+
     # show body as html or plain text
     my $ViewMode = 'BodyHTML';
 
