@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/CustomerTicketSearch.pm - Utilities for tickets
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: CustomerTicketSearch.pm,v 1.37.2.2 2010/06/24 18:13:20 dz Exp $
+# $Id: CustomerTicketSearch.pm,v 1.65.2.1 2011-08-23 12:45:25 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,10 +18,12 @@ use Kernel::System::CustomerUser;
 use Kernel::System::User;
 use Kernel::System::Priority;
 use Kernel::System::State;
+use Kernel::System::Queue;
 use Kernel::System::SearchProfile;
+use Kernel::System::CSV;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.37.2.2 $) [1];
+$VERSION = qw($Revision: 1.65.2.1 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -40,7 +42,9 @@ sub new {
     $Self->{CustomerUserObject}  = Kernel::System::CustomerUser->new(%Param);
     $Self->{PriorityObject}      = Kernel::System::Priority->new(%Param);
     $Self->{StateObject}         = Kernel::System::State->new(%Param);
+    $Self->{QueueObject}         = Kernel::System::Queue->new(%Param);
     $Self->{SearchProfileObject} = Kernel::System::SearchProfile->new(%Param);
+    $Self->{CSVObject}           = Kernel::System::CSV->new(%Param);
 
     $Self->{Config} = $Self->{ConfigObject}->Get("Ticket::Frontend::$Self->{Action}");
 
@@ -52,8 +56,8 @@ sub Run {
 
     my $Output;
 
-    # get confid data
-    $Self->{StartHit} = int $Self->{ParamObject}->GetParam( Param => 'StartHit' ) || 1;
+    # get config data
+    $Self->{StartHit} = int( $Self->{ParamObject}->GetParam( Param => 'StartHit' ) || 1 );
     $Self->{SearchLimit} = $Self->{ConfigObject}->Get('Ticket::CustomerTicketSearch::SearchLimit')
         || 200;
     $Self->{SearchPageShown}
@@ -64,6 +68,7 @@ sub Run {
     $Self->{Order} = $Self->{ParamObject}->GetParam( Param => 'Order' )
         || $Self->{ConfigObject}->Get('Ticket::CustomerTicketSearch::Order::Default')
         || 'Down';
+
     $Self->{Profile}        = $Self->{ParamObject}->GetParam( Param => 'Profile' )        || '';
     $Self->{SaveProfile}    = $Self->{ParamObject}->GetParam( Param => 'SaveProfile' )    || '';
     $Self->{TakeLastSearch} = $Self->{ParamObject}->GetParam( Param => 'TakeLastSearch' ) || '';
@@ -74,12 +79,15 @@ sub Run {
     if ( $Self->{ParamObject}->GetParam( Param => 'SearchTemplate' ) && $Self->{Profile} ) {
         return $Self->{LayoutObject}->Redirect(
             OP =>
-                "Action=CustomerTicketSearchSubaction=Search&TakeLastSearch=1&SaveProfile=1&Profile=$Self->{Profile}",
+                "Action=CustomerTicketSearch;Subaction=Search;TakeLastSearch=1;SaveProfile=1;Profile=$Self->{Profile}",
         );
     }
 
-    # get signle params
-    my %GetParam = ();
+    # remember exclude attributes
+    my @Excludes = $Self->{ParamObject}->GetArray( Param => 'Exclude' );
+
+    # get single params
+    my %GetParam;
 
     # load profiles string params (press load profile)
     if ( ( $Self->{Subaction} eq 'LoadProfile' && $Self->{Profile} ) || $Self->{TakeLastSearch} ) {
@@ -92,7 +100,7 @@ sub Run {
 
     # get search string params (get submitted params)
     else {
-        for (
+        for my $Key (
             qw(TicketNumber From To Cc Subject Body CustomerID ResultForm TimeSearchType StateType
             TicketFreeTime1
             TicketFreeTime1Start TicketFreeTime1StartDay TicketFreeTime1StartMonth
@@ -145,17 +153,17 @@ sub Run {
         {
 
             # get search string params (get submitted params)
-            $GetParam{$_} = $Self->{ParamObject}->GetParam( Param => $_ );
+            $GetParam{$Key} = $Self->{ParamObject}->GetParam( Param => $Key );
 
             # remove white space on the start and end
-            if ( $GetParam{$_} ) {
-                $GetParam{$_} =~ s/\s+$//g;
-                $GetParam{$_} =~ s/^\s+//g;
+            if ( $GetParam{$Key} ) {
+                $GetParam{$Key} =~ s/\s+$//g;
+                $GetParam{$Key} =~ s/^\s+//g;
             }
         }
 
         # get array params
-        for (
+        for my $Key (
             qw(StateIDs StateTypeIDs PriorityIDs OwnerIDs ResponsibleIDs
             TicketFreeKey1 TicketFreeText1 TicketFreeKey2 TicketFreeText2
             TicketFreeKey3 TicketFreeText3 TicketFreeKey4 TicketFreeText4
@@ -170,29 +178,36 @@ sub Run {
         {
 
             # get search array params (get submitted params)
-            my @Array = $Self->{ParamObject}->GetArray( Param => $_ );
+            my @Array = $Self->{ParamObject}->GetArray( Param => $Key );
             if (@Array) {
-                $GetParam{$_} = \@Array;
+                $GetParam{$Key} = \@Array;
             }
         }
     }
 
+    # check if item need to get excluded
+    for my $Exclude (@Excludes) {
+        if ( $GetParam{$Exclude} ) {
+            delete $GetParam{$Exclude};
+        }
+    }
+
     # get time option
     if ( !$GetParam{TimeSearchType} ) {
-        $GetParam{'TimeSearchType::None'} = 'checked';
+        $GetParam{'TimeSearchType::None'} = 'checked="checked"';
     }
     elsif ( $GetParam{TimeSearchType} eq 'TimePoint' ) {
-        $GetParam{'TimeSearchType::TimePoint'} = 'checked';
+        $GetParam{'TimeSearchType::TimePoint'} = 'checked="checked"';
     }
     elsif ( $GetParam{TimeSearchType} eq 'TimeSlot' ) {
-        $GetParam{'TimeSearchType::TimeSlot'} = 'checked';
+        $GetParam{'TimeSearchType::TimeSlot'} = 'checked="checked"';
     }
 
     # set result form env
     if ( !$GetParam{ResultForm} ) {
         $GetParam{ResultForm} = '';
     }
-    if ( $GetParam{ResultForm} eq 'Print' || $GetParam{ResultForm} eq 'CSV' ) {
+    if ( $GetParam{ResultForm} eq 'Print' ) {
         $Self->{SearchPageShown} = $Self->{SearchLimit};
     }
 
@@ -204,13 +219,13 @@ sub Run {
         );
         return $Self->{LayoutObject}->Attachment(
             Filename    => 'OpenSearchDescription.xml',
-            ContentType => "text/xml",
+            ContentType => 'application/opensearchdescription+xml',
             Content     => $Output,
             Type        => 'inline',
         );
     }
 
-    # show result site
+    # show result page
     if ( $Self->{Subaction} eq 'Search' && !$Self->{EraseTemplate} ) {
 
         # fill up profile name (e.g. with last-search)
@@ -248,7 +263,7 @@ sub Run {
         # get time settings
         if ( !$GetParam{TimeSearchType} ) {
 
-            # do noting ont time stuff
+            # do nothing with time stuff
         }
         elsif ( $GetParam{TimeSearchType} eq 'TimeSlot' ) {
             for (qw(Month Day)) {
@@ -333,7 +348,7 @@ sub Run {
                 $GetParam{ 'TicketFreeTime' . $_ . 'OlderDate' } = undef;
             }
             else {
-                $GetParam{ 'TicketFreeTime' . $_ } = 'checked';
+                $GetParam{ 'TicketFreeTime' . $_ } = 'checked="checked"';
                 if (
                     $GetParam{ 'TicketFreeTime' . $_ . 'StartDay' }
                     && $GetParam{ 'TicketFreeTime' . $_ . 'StartMonth' }
@@ -361,48 +376,40 @@ sub Run {
             }
         }
 
-        # focus of "From To Cc Subject Body"
-        for (qw(From To Cc Subject Body)) {
-            if ( defined( $GetParam{$_} ) && $GetParam{$_} ne '' ) {
-                $GetParam{$_} = "*$GetParam{$_}*";
-            }
-        }
-
         # perform ticket search
-        my $Counter     = 0;
-        my @ViewableIDs = $Self->{TicketObject}->TicketSearch(
-            Result          => 'ARRAY',
-            SortBy          => $Self->{SortBy},
-            OrderBy         => $Self->{Order},
-            Limit           => $Self->{SearchLimit},
-            CustomerUserID  => $Self->{UserID},
-            ConditionInline => $Self->{Config}->{ExtendedSearchCondition},
-            FullTextIndex   => 1,
+        my @ViewableTicketIDs = $Self->{TicketObject}->TicketSearch(
+            Result              => 'ARRAY',
+            SortBy              => $Self->{SortBy},
+            OrderBy             => $Self->{Order},
+            Limit               => $Self->{SearchLimit},
+            CustomerUserID      => $Self->{UserID},
+            ConditionInline     => $Self->{Config}->{ExtendedSearchCondition},
+            ContentSearchPrefix => '*',
+            ContentSearchSuffix => '*',
+            FullTextIndex       => 1,
             %GetParam,
         );
-        for (@ViewableIDs) {
-            $Counter++;
 
-            # build search result
-            if (
-                $Counter >= $Self->{StartHit}
-                && $Counter < ( $Self->{SearchPageShown} + $Self->{StartHit} )
-                )
-            {
+        # CSV output
+        if ( $GetParam{ResultForm} eq 'CSV' ) {
+            my @CSVHead;
+            my @CSVData;
+
+            for (@ViewableTicketIDs) {
 
                 # get first article data
-                my %Data = $Self->{TicketObject}->ArticleLastCustomerArticle(
+                my %Data = $Self->{TicketObject}->ArticleFirstArticle(
                     TicketID => $_,
                     Extended => 1,
                 );
 
+                $Data{Age} = $Self->{LayoutObject}->CustomerAge( Age => $Data{Age}, Space => ' ' );
+
                 # get whole article (if configured!)
-                if (
-                    $Self->{ConfigObject}->Get('CustomerSearchArticleTreeCSV')
-                    && $GetParam{ResultForm} eq 'CSV'
-                    )
-                {
-                    my @Article = $Self->{TicketObject}->ArticleGet( TicketID => $_ );
+                if ( $Self->{Config}->{SearchArticleCSVTree} && $GetParam{ResultForm} eq 'CSV' ) {
+                    my @Article = $Self->{TicketObject}->ArticleGet(
+                        TicketID => $_,
+                    );
                     for my $Articles (@Article) {
                         if ( $Articles->{Body} ) {
                             $Data{ArticleTree}
@@ -414,91 +421,124 @@ sub Run {
                     }
                 }
 
-                # customer info
-                my %CustomerData = ();
-                if ( $Data{CustomerUserID} ) {
-                    %CustomerData = $Self->{CustomerUserObject}->CustomerUserDataGet(
-                        User => $Data{CustomerUserID},
-                    );
-                }
-                elsif ( $Data{CustomerID} ) {
-                    %CustomerData = $Self->{CustomerUserObject}->CustomerUserDataGet(
-                        CustomerID => $Data{CustomerID},
-                    );
-                }
-
                 # customer info (customer name)
-                if ( $CustomerData{UserLogin} ) {
+                if ( $Data{CustomerUserID} ) {
                     $Data{CustomerName} = $Self->{CustomerUserObject}->CustomerName(
-                        UserLogin => $CustomerData{UserLogin},
+                        UserLogin => $Data{CustomerUserID},
                     );
                 }
 
                 # user info
                 my %UserInfo = $Self->{UserObject}->GetUserData(
-                    User   => $Data{Owner},
-                    Cached => 1
+                    User => $Data{Owner},
                 );
 
-                # generate ticket result
-                if ( $GetParam{ResultForm} eq 'CSV' ) {
+                # merge row data
+                my %Info = (
+                    %Data,
+                    %UserInfo,
+                    AccountedTime =>
+                        $Self->{TicketObject}->TicketAccountedTimeGet( TicketID => $_ ),
+                );
 
-                    # csv quote
-                    for ( keys %Data ) {
-                        $Data{$_} =~ s/"/""/g if ( $Data{$_} );
-                    }
-                    $Param{StatusTable} .= $Self->MaskCSVResult(
-                        %Data, %UserInfo,
-                        AccountedTime =>
-                            $Self->{TicketObject}->TicketAccountedTimeGet( TicketID => $_ ),
-                    ) . "\n";
+                # csv quote
+                if ( !@CSVHead ) {
+                    @CSVHead = @{ $Self->{Config}->{SearchCSVData} };
                 }
-                else {
-
-                    # Condense down the subject
-                    my $Subject = $Self->{TicketObject}->TicketSubjectClean(
-                        TicketNumber => $Data{TicketNumber},
-                        Subject => $Data{Subject} || '',
-                    );
-                    $Data{Age}
-                        = $Self->{LayoutObject}->CustomerAge( Age => $Data{Age}, Space => ' ' );
-
-                    # customer info string
-                    $Data{CustomerName} = '(' . $Data{CustomerName} . ')'
-                        if ( $Data{CustomerName} );
-
-                    # add blocks to template
-                    $Self->{LayoutObject}->Block(
-                        Name => 'Record',
-                        Data => {
-                            %Data,
-                            Subject => $Subject,
-                            %UserInfo,
-                        },
-                    );
+                my @Data;
+                for (@CSVHead) {
+                    push @Data, $Info{$_};
                 }
+                push @CSVData, \@Data;
             }
+
+            # get Separator from language file
+            my $UserCSVSeparator = $Self->{LayoutObject}->{LanguageObject}->{Separator};
+
+            if ( $Self->{ConfigObject}->Get('PreferencesGroups')->{CSVSeparator}->{Active} ) {
+                my %UserData = $Self->{UserObject}->GetUserData( UserID => $Self->{UserID} );
+                $UserCSVSeparator = $UserData{UserCSVSeparator};
+            }
+            my $CSV = $Self->{CSVObject}->Array2CSV(
+                Head      => \@CSVHead,
+                Data      => \@CSVData,
+                Separator => $UserCSVSeparator,
+            );
+
+            # return csv to download
+            my $CSVFile = 'ticket_search';
+            my ( $s, $m, $h, $D, $M, $Y ) = $Self->{TimeObject}->SystemTime2Date(
+                SystemTime => $Self->{TimeObject}->SystemTime(),
+            );
+            $M = sprintf( "%02d", $M );
+            $D = sprintf( "%02d", $D );
+            $h = sprintf( "%02d", $h );
+            $m = sprintf( "%02d", $m );
+            return $Self->{LayoutObject}->Attachment(
+                Filename    => $CSVFile . "_" . "$Y-$M-$D" . "_" . "$h-$m.csv",
+                ContentType => "text/csv; charset=" . $Self->{LayoutObject}->{UserCharset},
+                Content     => $CSV,
+            );
         }
+        elsif ( $GetParam{ResultForm} eq 'Print' ) {
+            for my $TicketID (@ViewableTicketIDs) {
 
-        # start html page
-        my $Output = $Self->{LayoutObject}->CustomerHeader();
-        $Output .= $Self->{LayoutObject}->CustomerNavigationBar();
+                # get first article data
+                my %Article = $Self->{TicketObject}->ArticleLastCustomerArticle(
+                    TicketID => $TicketID,
+                    Extended => 1,
+                );
 
-        # build search navigation bar
-        my %PageNav = $Self->{LayoutObject}->PageNavBar(
-            Limit     => $Self->{SearchLimit},
-            StartHit  => $Self->{StartHit},
-            PageShown => $Self->{SearchPageShown},
-            AllHits   => $Counter,
-            Action    => "Action=CustomerTicketSearch&Subaction=Search",
-            Link =>
-                "Profile=$Self->{Profile}&SortBy=$Self->{SortBy}&Order=$Self->{Order}&TakeLastSearch=1&",
-        );
+                # customer info
+                my %CustomerData;
+                if ( $Article{CustomerUserID} ) {
+                    %CustomerData = $Self->{CustomerUserObject}->CustomerUserDataGet(
+                        User => $Article{CustomerUserID},
+                    );
+                }
+                elsif ( $Article{CustomerID} ) {
+                    %CustomerData = $Self->{CustomerUserObject}->CustomerUserDataGet(
+                        CustomerID => $Article{CustomerID},
+                    );
+                }
 
-        # build shown ticket
-        if ( $GetParam{ResultForm} eq 'Print' ) {
-            $Output = $Self->{LayoutObject}->PrintHeader( Width => 800 );
-            if ( @ViewableIDs == $Self->{SearchLimit} ) {
+                # customer info (customer name)
+                if ( $CustomerData{UserLogin} ) {
+                    $Article{CustomerName} = $Self->{CustomerUserObject}->CustomerName(
+                        UserLogin => $CustomerData{UserLogin},
+                    );
+                }
+
+                # user info
+                my %Owner = $Self->{UserObject}->GetUserData(
+                    User => $Article{Owner},
+                );
+
+                # Condense down the subject
+                my $Subject = $Self->{TicketObject}->TicketSubjectClean(
+                    TicketNumber => $Article{TicketNumber},
+                    Subject => $Article{Subject} || '',
+                );
+                $Article{Age}
+                    = $Self->{LayoutObject}->CustomerAge( Age => $Article{Age}, Space => ' ' );
+
+                # customer info string
+                if ( $Article{CustomerName} ) {
+                    $Article{CustomerName} = '(' . $Article{CustomerName} . ')';
+                }
+
+                # add blocks to template
+                $Self->{LayoutObject}->Block(
+                    Name => 'Record',
+                    Data => {
+                        %Article,
+                        Subject => $Subject,
+                        %Owner,
+                    },
+                );
+            }
+            my $Output = $Self->{LayoutObject}->PrintHeader( Width => 800 );
+            if ( @ViewableTicketIDs == $Self->{SearchLimit} ) {
                 $Param{Warning} = '$Text{"Reached max. count of %s search hits!", "'
                     . $Self->{SearchLimit} . '"}';
             }
@@ -512,27 +552,253 @@ sub Run {
 
             # return output
             return $Output;
-        }
-        elsif ( $GetParam{ResultForm} eq 'CSV' ) {
 
-            # return csv to download
-            my $CSVFile = 'search';
-            my ( $Sec, $Min, $Hour, $Day, $Month, $Year ) = $Self->{TimeObject}->SystemTime2Date(
-                SystemTime => $Self->{TimeObject}->SystemTime(),
-            );
-            return $Self->{LayoutObject}->Attachment(
-                Filename    => $CSVFile . '_' . "$Year-$Month-$Day" . '_' . "$Hour-$Min.csv",
-                ContentType => "text/csv",
-                Content     => $Param{StatusTable},
-            );
         }
+
+        my $Counter = 0;
+
+        # if there are results to show
+        if (@ViewableTicketIDs) {
+            for my $TicketID (@ViewableTicketIDs) {
+                $Counter++;
+
+                # build search result
+                if (
+                    $Counter >= $Self->{StartHit}
+                    && $Counter < ( $Self->{SearchPageShown} + $Self->{StartHit} )
+                    )
+                {
+
+                    # get first article data
+                    my %Article = $Self->{TicketObject}->ArticleLastCustomerArticle(
+                        TicketID => $TicketID,
+                        Extended => 1,
+                    );
+
+                    # customer info
+                    my %CustomerData;
+                    if ( $Article{CustomerUserID} ) {
+                        %CustomerData = $Self->{CustomerUserObject}->CustomerUserDataGet(
+                            User => $Article{CustomerUserID},
+                        );
+                    }
+                    elsif ( $Article{CustomerID} ) {
+                        %CustomerData = $Self->{CustomerUserObject}->CustomerUserDataGet(
+                            CustomerID => $Article{CustomerID},
+                        );
+                    }
+
+                    # customer info (customer name)
+                    if ( $CustomerData{UserLogin} ) {
+                        $Article{CustomerName} = $Self->{CustomerUserObject}->CustomerName(
+                            UserLogin => $CustomerData{UserLogin},
+                        );
+                    }
+
+                    # user info
+                    my %Owner = $Self->{UserObject}->GetUserData(
+                        User => $Article{Owner},
+                    );
+
+                    # Condense down the subject
+                    my $Subject = $Self->{TicketObject}->TicketSubjectClean(
+                        TicketNumber => $Article{TicketNumber},
+                        Subject => $Article{Subject} || '',
+                    );
+                    $Article{Age}
+                        = $Self->{LayoutObject}->CustomerAge( Age => $Article{Age}, Space => ' ' );
+
+                    # customer info string
+                    if ( $Article{CustomerName} ) {
+                        $Article{CustomerName} = '(' . $Article{CustomerName} . ')';
+                    }
+
+                    # add blocks to template
+                    $Self->{LayoutObject}->Block(
+                        Name => 'Record',
+                        Data => {
+                            %Article,
+                            Subject => $Subject,
+                            %Owner,
+                        },
+                    );
+                }
+            }
+        }
+
+        # otherwise show a no data found msg
         else {
-            $Output .= $Self->{LayoutObject}->Output(
-                TemplateFile => 'CustomerTicketSearchResultShort',
-                Data => { %Param, %PageNav, Profile => $Self->{Profile}, },
+            $Self->{LayoutObject}->Block( Name => 'NoDataFoundMsg' );
+        }
+
+        # show attributes used for search
+        my %IDMap = (
+            StateIDs => {
+                Name        => 'State',
+                Object      => 'StateObject',
+                Methode     => 'StateLookup',
+                Key         => 'StateID',
+                Translation => 1,
+            },
+            StateTypeIDs => {
+                Name        => 'StateType',
+                Object      => 'StateObject',
+                Methode     => 'StateTypeLookup',
+                Key         => 'StateTypeID',
+                Translation => 1,
+            },
+            PriorityIDs => {
+                Name        => 'Priority',
+                Object      => 'PriorityObject',
+                Methode     => 'PriorityLookup',
+                Key         => 'PriorityID',
+                Translation => 1,
+            },
+            QueueIDs => {
+                Name        => 'Queue',
+                Object      => 'QueueObject',
+                Methode     => 'QueueLookup',
+                Key         => 'QueueID',
+                Translation => 0,
+            },
+            OwnerIDs => {
+                Name        => 'Owner',
+                Object      => 'UserObject',
+                Methode     => 'UserLookup',
+                Key         => 'UserID',
+                Translation => 0,
+            },
+            ResponsibleIDs => {
+                Name        => 'Responsible',
+                Object      => 'UserObject',
+                Methode     => 'UserLookup',
+                Key         => 'UserID',
+                Translation => 0,
+            },
+        );
+        for my $Key (
+            qw(TicketNumber From To Cc Subject Body CustomerID TimeSearchType StateType
+            StateIDs StateTypeIDs PriorityIDs OwnerIDs ResponsibleIDs
+            )
+            )
+        {
+            next if !$GetParam{$Key};
+            my $Attribute = $IDMap{$Key}->{Name}   || $Key;
+            my $Object    = $IDMap{$Key}->{Object} || '';
+            my $Method    = $IDMap{$Key}->{Methode};
+            my $MethodKey = $IDMap{$Key}->{Key};
+            my $Translation = $IDMap{$Key}->{Translation};
+            my $Value;
+
+            if ( ref $GetParam{$Key} eq 'ARRAY' ) {
+                for my $ItemRaw ( @{ $GetParam{$Key} } ) {
+                    my $Item = $ItemRaw;
+                    if ($Value) {
+                        $Value .= '+';
+                    }
+                    if ( $Self->{$Object} ) {
+                        $Item = $Self->{$Object}->$Method( $MethodKey => $Item );
+                        if ($Translation) {
+                            $Item = $Self->{LayoutObject}->{LanguageObject}->Get($Item);
+                        }
+                    }
+                    $Value .= $Item;
+                }
+            }
+            else {
+                my $Item = $GetParam{$Key};
+                if ( $Self->{$Object} ) {
+                    $Item = $Self->{$Object}->$Method( $MethodKey => $Item );
+                    if ($Translation) {
+                        $Item = $Self->{LayoutObject}->{LanguageObject}->Get($Item);
+                    }
+                }
+                $Value = $Item;
+            }
+
+            if ( $Key ne 'TimeSearchType' ) {
+                $Self->{LayoutObject}->Block(
+                    Name => 'SearchTerms',
+                    Data => {
+                        %Param,
+                        Attribute => $Attribute,
+                        Key       => $Key,
+                        Value     => $Value,
+                    },
+                );
+            }
+        }
+
+        my $Link = 'Profile=' . $Self->{LayoutObject}->LinkEncode( $Self->{Profile} ) . ';';
+        $Link .= 'SortBy=' . $Self->{LayoutObject}->LinkEncode( $Self->{SortBy} ) . ';';
+        $Link .= 'Order=' . $Self->{LayoutObject}->LinkEncode( $Self->{Order} ) . ';';
+        $Link .= 'TakeLastSearch=1;';
+
+        # build search navigation bar
+        my %PageNav = $Self->{LayoutObject}->PageNavBar(
+            Limit     => $Self->{SearchLimit},
+            StartHit  => $Self->{StartHit},
+            PageShown => $Self->{SearchPageShown},
+            AllHits   => $Counter,
+            Action    => "Action=CustomerTicketSearch;Subaction=Search",
+            Link      => $Link,
+            IDPrefix  => "CustomerTicketSearch",
+        );
+
+        # show footer filter - show only if more the one page is available
+        if ( $PageNav{TotalHits} && ( $PageNav{TotalHits} > $Self->{SearchPageShown} ) ) {
+            $Self->{LayoutObject}->Block(
+                Name => 'Pagination',
+                Data => {
+                    %Param,
+                    %PageNav,
+                },
             );
         }
 
+        my $Order = 'Down';
+        if ( $Self->{Order} eq 'Down' ) {
+            $Order = 'Up';
+        }
+        my $Sort       = '';
+        my $StateSort  = '';
+        my $TicketSort = '';
+        my $AgeSort    = '';
+
+        # this sets the opposit to the $Order
+        if ( $Order eq 'Down' ) {
+            $Sort = 'SortAscending';
+        }
+        if ( $Order eq 'Up' ) {
+            $Sort = 'SortDescending';
+        }
+
+        if ( $Self->{SortBy} eq 'State' ) {
+            $StateSort = $Sort;
+        }
+        if ( $Self->{SortBy} eq 'Ticket' ) {
+            $TicketSort = $Sort;
+        }
+        if ( $Self->{SortBy} eq 'Age' ) {
+            $AgeSort = $Sort;
+        }
+
+        # start html page
+        my $Output = $Self->{LayoutObject}->CustomerHeader();
+        $Output .= $Self->{LayoutObject}->CustomerNavigationBar();
+        $Output .= $Self->{LayoutObject}->Output(
+            TemplateFile => 'CustomerTicketSearchResultShort',
+            Data         => {
+                %Param,
+                %PageNav,
+                Order      => $Order,
+                StateSort  => $StateSort,
+                TicketSort => $TicketSort,
+                AgeSort    => $AgeSort,
+                Profile    => $Self->{Profile},
+            },
+        );
+
         # build footer
         $Output .= $Self->{LayoutObject}->CustomerFooter();
         return $Output;
@@ -555,7 +821,7 @@ sub Run {
         }
 
         # get free text config options
-        my %TicketFreeText = ();
+        my %TicketFreeText;
         for ( 1 .. 16 ) {
             $TicketFreeText{"TicketFreeKey$_"} = $Self->{TicketObject}->TicketFreeTextGet(
                 Type           => "TicketFreeKey$_",
@@ -591,7 +857,7 @@ sub Run {
 sub MaskForm {
     my ( $Self, %Param ) = @_;
 
-    $Param{'ResultFormStrg'} = $Self->{LayoutObject}->OptionStrgHashRef(
+    $Param{ResultFormStrg} = $Self->{LayoutObject}->BuildSelection(
         Data => {
             Normal => 'Normal',
             Print  => 'Print',
@@ -600,40 +866,52 @@ sub MaskForm {
         Name => 'ResultForm',
         SelectedID => $Param{ResultForm} || 'Normal',
     );
-    $Param{'StatesStrg'} = $Self->{LayoutObject}->OptionStrgHashRef(
+    $Param{ProfilesStrg} = $Self->{LayoutObject}->BuildSelection(
+        Data => {
+            '', '-',
+            $Self->{SearchProfileObject}->SearchProfileList(
+                Base      => 'CustomerTicketSearch',
+                UserLogin => $Self->{UserLogin},
+            ),
+        },
+        Name       => 'Profile',
+        SelectedID => $Param{Profile},
+    );
+
+    $Param{StatesStrg} = $Self->{LayoutObject}->BuildSelection(
         Data => {
             $Self->{StateObject}->StateList(
                 UserID => $Self->{UserID},
                 Action => $Self->{Action},
-                )
+            ),
         },
-        Name               => 'StateIDs',
-        Multiple           => 1,
-        Size               => 5,
-        SelectedIDRefArray => $Param{StateIDs},
+        Name       => 'StateIDs',
+        Multiple   => 1,
+        Size       => 5,
+        SelectedID => $Param{StateIDs},
     );
-    $Param{'StateTypeStrg'} = $Self->{LayoutObject}->OptionStrgHashRef(
+    $Param{StateTypeStrg} = $Self->{LayoutObject}->BuildSelection(
         Data => {
-            'Open'   => 'open',
-            'Closed' => 'closed',
+            Open   => 'open',
+            Closed => 'closed',
         },
         Name       => 'StateType',
         Size       => 5,
         SelectedID => $Param{StateType},
     );
-    $Param{'PrioritiesStrg'} = $Self->{LayoutObject}->OptionStrgHashRef(
+    $Param{PrioritiesStrg} = $Self->{LayoutObject}->BuildSelection(
         Data => {
             $Self->{PriorityObject}->PriorityList(
                 UserID => $Self->{UserID},
                 Action => $Self->{Action},
             ),
         },
-        Name               => 'PriorityIDs',
-        Multiple           => 1,
-        Size               => 5,
-        SelectedIDRefArray => $Param{PriorityIDs},
+        Name       => 'PriorityIDs',
+        Multiple   => 1,
+        Size       => 5,
+        SelectedID => $Param{PriorityIDs},
     );
-    $Param{'TicketCreateTimePoint'} = $Self->{LayoutObject}->OptionStrgHashRef(
+    $Param{TicketCreateTimePoint} = $Self->{LayoutObject}->BuildSelection(
         Data => {
             1  => ' 1',
             2  => ' 2',
@@ -698,15 +976,15 @@ sub MaskForm {
         Name       => 'TicketCreateTimePoint',
         SelectedID => $Param{TicketCreateTimePoint},
     );
-    $Param{'TicketCreateTimePointStart'} = $Self->{LayoutObject}->OptionStrgHashRef(
+    $Param{TicketCreateTimePointStart} = $Self->{LayoutObject}->BuildSelection(
         Data => {
-            'Last'   => 'last',
-            'Before' => 'before',
+            Last   => 'last',
+            Before => 'before',
         },
         Name => 'TicketCreateTimePointStart',
         SelectedID => $Param{TicketCreateTimePointStart} || 'Last',
     );
-    $Param{'TicketCreateTimePointFormat'} = $Self->{LayoutObject}->OptionStrgHashRef(
+    $Param{TicketCreateTimePointFormat} = $Self->{LayoutObject}->BuildSelection(
         Data => {
             minute => 'minute(s)',
             hour   => 'hour(s)',
@@ -720,28 +998,32 @@ sub MaskForm {
     );
     $Param{TicketCreateTimeStart} = $Self->{LayoutObject}->BuildDateSelection(
         %Param,
-        Prefix   => 'TicketCreateTimeStart',
-        Format   => 'DateInputFormat',
-        DiffTime => -( ( 60 * 60 * 24 ) * 30 ),
+        Prefix                     => 'TicketCreateTimeStart',
+        TicketCreateTimeStartClass => 'DateSelection',
+        Format                     => 'DateInputFormat',
+        DiffTime                   => -( ( 60 * 60 * 24 ) * 30 ),
     );
     $Param{TicketCreateTimeStop} = $Self->{LayoutObject}->BuildDateSelection(
         %Param,
-        Prefix => 'TicketCreateTimeStop',
-        Format => 'DateInputFormat',
+        Prefix                    => 'TicketCreateTimeStop',
+        TicketCreateTimeStopClass => 'DateSelection',
+        Format                    => 'DateInputFormat',
     );
 
     for ( 1 .. 6 ) {
         $Param{ 'TicketFreeTime' . $_ . 'Start' } = $Self->{LayoutObject}->BuildDateSelection(
             %Param,
-            Prefix   => 'TicketFreeTime' . $_ . 'Start',
-            Format   => 'DateInputFormat',
-            DiffTime => -( ( 60 * 60 * 24 ) * 30 ),
+            Prefix                               => 'TicketFreeTime' . $_ . 'Start',
+            'TicketFreeTime' . $_ . 'StartClass' => 'DateSelection',
+            Format                               => 'DateInputFormat',
+            DiffTime                             => -( ( 60 * 60 * 24 ) * 30 ),
         );
         $Param{ 'TicketFreeTime' . $_ . 'Stop' } = $Self->{LayoutObject}->BuildDateSelection(
             %Param,
-            Prefix   => 'TicketFreeTime' . $_ . 'Stop',
-            Format   => 'DateInputFormat',
-            DiffTime => +( ( 60 * 60 * 24 ) * 30 ),
+            Prefix                              => 'TicketFreeTime' . $_ . 'Stop',
+            'TicketFreeTime' . $_ . 'StopClass' => 'DateSelection',
+            Format                              => 'DateInputFormat',
+            DiffTime                            => +( ( 60 * 60 * 24 ) * 30 ),
         );
     }
 
@@ -751,29 +1033,27 @@ sub MaskForm {
         Data => { %Param, },
     );
     for my $Count ( 1 .. 16 ) {
-        if ( $Self->{Config}->{'TicketFreeText'}->{$Count} ) {
-            $Self->{LayoutObject}->Block(
-                Name => 'FreeText',
-                Data => {
-                    TicketFreeKeyField  => $Param{ 'TicketFreeKeyField' . $Count },
-                    TicketFreeTextField => $Param{ 'TicketFreeTextField' . $Count },
-                },
-            );
-        }
+        next if !$Self->{Config}->{TicketFreeText}->{$Count};
+        $Self->{LayoutObject}->Block(
+            Name => 'FreeText',
+            Data => {
+                TicketFreeKeyField  => $Param{ 'TicketFreeKeyField' . $Count },
+                TicketFreeTextField => $Param{ 'TicketFreeTextField' . $Count },
+            },
+        );
     }
     for my $Count ( 1 .. 6 ) {
-        if ( $Self->{Config}->{'TicketFreeTime'}->{$Count} ) {
-            $Self->{LayoutObject}->Block(
-                Name => 'FreeTime',
-                Data => {
-                    TicketFreeTimeKey => $Self->{ConfigObject}->Get( 'TicketFreeTimeKey' . $Count ),
-                    TicketFreeTime    => $Param{ 'TicketFreeTime' . $Count },
-                    TicketFreeTimeStart => $Param{ 'TicketFreeTime' . $Count . 'Start' },
-                    TicketFreeTimeStop  => $Param{ 'TicketFreeTime' . $Count . 'Stop' },
-                    Count               => $Count,
-                },
-            );
-        }
+        next if !$Self->{Config}->{TicketFreeTime}->{$Count};
+        $Self->{LayoutObject}->Block(
+            Name => 'FreeTime',
+            Data => {
+                TicketFreeTimeKey   => $Self->{ConfigObject}->Get( 'TicketFreeTimeKey' . $Count ),
+                TicketFreeTime      => $Param{ 'TicketFreeTime' . $Count },
+                TicketFreeTimeStart => $Param{ 'TicketFreeTime' . $Count . 'Start' },
+                TicketFreeTimeStop  => $Param{ 'TicketFreeTime' . $Count . 'Stop' },
+                Count               => $Count,
+            },
+        );
     }
 
     # html search mask output
