@@ -1,8 +1,8 @@
 # --
 # Kernel/System/MailAccount/POP3.pm - lib for pop3 accounts
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
 # --
-# $Id: POP3.pm,v 1.9 2011/03/09 13:41:55 mb Exp $
+# $Id: POP3.pm,v 1.8 2010-01-13 17:02:10 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,7 +17,7 @@ use Net::POP3;
 use Kernel::System::PostMaster;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.9 $) [1];
+$VERSION = qw($Revision: 1.8 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -161,7 +161,7 @@ sub Fetch {
                 $Self->{LogObject}->Log(
                     Priority => 'error',
                     Message => "$AuthType: Can't fetch email $NOM from $Param{Login}/$Param{Host}. "
-                        . "Email too big ($MessageSize KB - max $MaxEmailSize KB)!",
+                        . "Email to big ($MessageSize KB - max $MaxEmailSize KB)!",
                 );
             }
             else {
