@@ -1,6 +1,8 @@
 # --
 # Kernel/System/Web/InterfaceAgent.pm - the agent interface file (incl. auth)
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# --
+# $Id: InterfaceAgent.pm,v 1.58.2.3 2011-11-21 10:29:00 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,8 +14,10 @@ package Kernel::System::Web::InterfaceAgent;
 use strict;
 use warnings;
 
-use vars qw(@INC);
+use vars qw($VERSION @INC);
+$VERSION = qw($Revision: 1.58.2.3 $) [1];
 
+# all framework needed modules
 use Kernel::Config;
 use Kernel::System::Log;
 use Kernel::System::Main;
@@ -48,10 +52,7 @@ create agent web interface object
     use Kernel::System::Web::InterfaceAgent;
 
     my $Debug = 0;
-    my $InterfaceAgent = Kernel::System::Web::InterfaceAgent->new(
-        Debug      => $Debug,
-        WebRequest => CGI::Fast->new(), # optional, e. g. if fast cgi is used, the CGI object is already provided
-    );
+    my $InterfaceAgent = Kernel::System::Web::InterfaceAgent->new(Debug => $Debug);
 
 =cut
 
@@ -89,7 +90,6 @@ sub new {
             Message  => 'Global handle started...',
         );
     }
-
     return $Self;
 }
 
@@ -122,7 +122,7 @@ sub Run {
         Subaction    => '',
         RequestedURL => $QueryString,
     };
-    for my $Key ( sort keys %{$FrameworkParams} ) {
+    for my $Key ( keys %{$FrameworkParams} ) {
         $Param{$Key} = $Self->{ParamObject}->GetParam( Param => $Key )
             || $FrameworkParams->{$Key};
     }
@@ -162,7 +162,7 @@ sub Run {
 
     # application and add-on application common objects
     my %CommonObject = %{ $Self->{ConfigObject}->Get('Frontend::CommonObject') };
-    for my $Key ( sort keys %CommonObject ) {
+    for my $Key ( keys %CommonObject ) {
         if ( $Self->{MainObject}->Require( $CommonObject{$Key} ) ) {
             $Self->{$Key} = $CommonObject{$Key}->new( %{$Self} );
         }
@@ -177,7 +177,7 @@ sub Run {
 
     # get common application and add-on application params
     my %CommonObjectParam = %{ $Self->{ConfigObject}->Get('Frontend::CommonParam') };
-    for my $Key ( sort keys %CommonObjectParam ) {
+    for my $Key ( keys %CommonObjectParam ) {
         $Param{$Key} = $Self->{ParamObject}->GetParam( Param => $Key ) || $CommonObjectParam{$Key};
     }
 
@@ -191,8 +191,8 @@ sub Run {
         my $LayoutObject = Kernel::Output::HTML::Layout->new( %{$Self}, Lang => $Param{Lang}, );
 
         # get params
-        my $PostUser = $Self->{ParamObject}->GetParam( Param => 'User' ) || '';
-        my $PostPw = $Self->{ParamObject}->GetParam( Param => 'Password', Raw => 1 ) || '';
+        my $PostUser = $Self->{ParamObject}->GetParam( Param => 'User' )     || '';
+        my $PostPw   = $Self->{ParamObject}->GetParam( Param => 'Password' ) || '';
 
         # create AuthObject
         my $AuthObject = Kernel::System::Auth->new( %{$Self} );
@@ -263,7 +263,7 @@ sub Run {
                 Type   => $Type,
                 UserID => $UserData{UserID},
             );
-            for ( sort keys %GroupData ) {
+            for ( keys %GroupData ) {
                 if ( $Type eq 'rw' ) {
                     $UserData{"UserIsGroup[$GroupData{$_}]"} = 'Yes';
                 }
@@ -273,28 +273,28 @@ sub Run {
             }
         }
 
-        # create new session id
-        my $NewSessionID = $Self->{SessionObject}->CreateSessionID(
-            %UserData,
-            UserLastRequest => $Self->{TimeObject}->SystemTime(),
-            UserType        => 'User',
-        );
+        my $NewSessionID;
 
-        # show error message if no session id has been created
-        if ( !$NewSessionID ) {
+        # verify if the login and password should be saved in the session
+        if ( $Self->{ConfigObject}->Get("SessionSaveLoginPasswd") ) {
 
-            # get error message
-            my $Error = $Self->{SessionObject}->SessionIDErrorMessage() || '';
+            # create new session id
+            $NewSessionID = $Self->{SessionObject}->CreateSessionID(
+                _UserLogin => $PostUser,
+                _UserPw    => $PostPw,
+                %UserData,
+                UserLastRequest => $Self->{TimeObject}->SystemTime(),
+                UserType        => 'User',
+            );
+        }
+        else {
 
-            # output error message
-            $LayoutObject->Print(
-                Output => \$LayoutObject->Login(
-                    Title   => 'Login',
-                    Message => $Error,
-                    %Param,
-                ),
+            # create new session id
+            $NewSessionID = $Self->{SessionObject}->CreateSessionID(
+                %UserData,
+                UserLastRequest => $Self->{TimeObject}->SystemTime(),
+                UserType        => 'User',
             );
-            return;
         }
 
         # set time zone offset if TimeZoneFeature is active
@@ -304,7 +304,7 @@ sub Run {
             && $LayoutObject->{BrowserJavaScriptSupport}
             )
         {
-            my $TimeOffset = $Self->{ParamObject}->GetParam( Param => 'TimeOffset' ) || 0;
+            my $TimeOffset = $Self->{ParamObject}->GetParam( Param => 'TimeOffset' ) || '';
             if ( $TimeOffset > 0 ) {
                 $TimeOffset = '-' . ( $TimeOffset / 60 );
             }
@@ -362,7 +362,7 @@ sub Run {
         return 1;
     }
 
-    # logout
+    # Logout
     elsif ( $Param{Action} eq 'Logout' ) {
 
         # check session id
@@ -385,7 +385,7 @@ sub Run {
             $LayoutObject->Print(
                 Output => \$LayoutObject->Login(
                     Title   => 'Logout',
-                    Message => 'Session invalid. Please log in again.',
+                    Message => 'Invalid SessionID!',
                     %Param,
                 ),
             );
@@ -410,9 +410,6 @@ sub Run {
             %UserData,
         );
 
-        # Prevent CSRF attacks
-        $LayoutObject->ChallengeTokenCheck();
-
         # remove session id
         if ( !$Self->{SessionObject}->RemoveSessionID( SessionID => $Param{SessionID} ) ) {
             $LayoutObject->FatalError(
@@ -434,7 +431,7 @@ sub Run {
         $LayoutObject->Print(
             Output => \$LayoutObject->Login(
                 Title   => 'Logout',
-                Message => 'Logout successful. Thank you for using %s!", "$Config{"ProductName"}',
+                Message => 'Logout successful. Thank you for using OTRS!',
                 %Param,
             ),
         );
@@ -470,7 +467,7 @@ sub Run {
                 Key   => 'UserToken',
                 Value => $Token,
             );
-            for my $UserID ( sort keys %UserList ) {
+            for my $UserID ( keys %UserList ) {
                 my %UserData = $Self->{UserObject}->GetUserData(
                     UserID => $UserID,
                     Valid  => 1,
@@ -515,7 +512,7 @@ sub Run {
                 || 'ERROR: NotificationBodyLostPasswordToken is missing!';
             my $Subject = $Self->{ConfigObject}->Get('NotificationSubjectLostPasswordToken')
                 || 'ERROR: NotificationSubjectLostPasswordToken is missing!';
-            for ( sort keys %UserData ) {
+            for ( keys %UserData ) {
                 $Body =~ s/<OTRS_$_>/$UserData{$_}/gi;
             }
             my $Sent = $EmailObject->Send(
@@ -569,7 +566,7 @@ sub Run {
             || 'New Password is: <OTRS_NEWPW>';
         my $Subject = $Self->{ConfigObject}->Get('NotificationSubjectLostPassword')
             || 'New Password!';
-        for ( sort keys %UserData ) {
+        for ( keys %UserData ) {
             $Body =~ s/<OTRS_$_>/$UserData{$_}/gi;
         }
         my $Sent = $EmailObject->Send(
@@ -680,13 +677,15 @@ sub Run {
             $LayoutObject->Print(
                 Output => \$LayoutObject->Login(
                     Title   => 'Login',
-                    Message => $Self->{SessionObject}->SessionIDErrorMessage(),
+                    Message => $Self->{SessionObject}->CheckSessionIDMessage(),
                     %Param,
                 ),
             );
             return;
         }
 
+        # run module
+
         # get session data
         my %UserData = $Self->{SessionObject}->GetSessionIDData(
             SessionID => $Param{SessionID},
@@ -868,9 +867,7 @@ sub Run {
                 $QueryString = 'Action=' . $Param{Action} . '&Subaction=' . $Param{Subaction};
             }
             my $File = $Self->{ConfigObject}->Get('PerformanceLog::File');
-            ## no critic
             if ( open my $Out, '>>', $File ) {
-                ## use critic
                 print $Out time()
                     . '::Agent::'
                     . ( time() - $Self->{PerformanceLogStart} )
@@ -932,3 +929,9 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
+
+=head1 VERSION
+
+$Revision: 1.58.2.3 $ $Date: 2011-11-21 10:29:00 $
+
+=cut
