@@ -1,9 +1,9 @@
 #!/usr/bin/perl -w
 # --
 # bin/otrs.xml2sql.pl - a xml 2 sql processor
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
 # --
-# $Id: otrs.xml2sql.pl,v 1.7 2011/11/03 21:00:04 mb Exp $
+# $Id: otrs.xml2sql.pl,v 1.3 2010-08-06 17:49:20 cr Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -40,18 +40,15 @@ use Kernel::System::Main;
 use Kernel::System::XML;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.7 $) [1];
+$VERSION = qw($Revision: 1.3 $) [1];
 
 my %Opts = ();
 getopt( 'hton', \%Opts );
-if ( $Opts{'h'} || !%Opts ) {
-    print <<"EOF";
-$0 <Revision $VERSION> - tool to generate database specific SQL from the XML database definition files used by OTRS
-
-Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
-
-Usage: $0 -t <DATABASE_TYPE> (or 'all') [-o <OUTPUTDIR> -n <NAME> -s <SPLIT_FILES>]
-EOF
+if ( $Opts{'h'} ) {
+    print "xml2sql.pl <Revision $VERSION> - xml2sql\n";
+    print "Copyright (C) 2001-2010 OTRS AG, http://otrs.org/\n";
+    print "usage: xml2sql.pl -t <DATABASE_TYPE> (or 'all') ";
+    print "[-o <OUTPUTDIR> -n <NAME> -s <SPLIT_FILES>]\n";
     exit 1;
 }
 
@@ -112,11 +109,8 @@ for my $DatabaseType (@DatabaseType) {
     );
     $CommonObject{MainObject} = Kernel::System::Main->new(%CommonObject);
     $CommonObject{TimeObject} = Kernel::System::Time->new(%CommonObject);
-    $CommonObject{DBObject}   = Kernel::System::DB->new(
-        %CommonObject,
-        AutoConnectNo => 1,    # don't try with foreign drivers
-    );
-    $CommonObject{XMLObject} = Kernel::System::XML->new(%CommonObject);
+    $CommonObject{DBObject}   = Kernel::System::DB->new(%CommonObject);
+    $CommonObject{XMLObject}  = Kernel::System::XML->new(%CommonObject);
 
     # parse xml package
     my @XMLARRAY = $CommonObject{XMLObject}->XMLParse( String => $FileString );
@@ -183,7 +177,6 @@ sub Dump {
 
     if ($StdOut) {
         open my $OutHandle, '>', $Filename or die "Can't write: $!";
-        binmode $OutHandle, ':utf8';
         print "writing: $Filename\n";
         print $OutHandle $Head;
         for my $Item ( @{$SQL} ) {
