@@ -1,6 +1,8 @@
 // --
 // Core.Installer.js - provides the special module functions for Installer
-// Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
+// Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+// --
+// $Id: Core.Installer.js,v 1.4.2.1 2011-03-18 06:35:04 mp Exp $
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -38,7 +40,7 @@ InstallerDBStart
     /**
      * @function
      * @return nothing
-     *      This function displays the results for the database credentials
+     *      This function display the results for the check on the database
      */
     function CheckDBDataCallback(json) {
         if (parseInt(json['Successful']) < 1) {
@@ -48,7 +50,7 @@ InstallerDBStart
         }
         else {
             alert(Core.Config.Get('Installer.CheckDBDataLabel'));
-            $('#FormDBSubmit').removeAttr('disabled');
+            $('#FormDBSubmit').attr('disabled', false);
             $('fieldset.ErrorMsg, fieldset.CheckDB').hide();
             $('fieldset.HideMe, div.HideMe').show();
         }
@@ -57,8 +59,8 @@ InstallerDBStart
     /**
      * @function
      * @description
-     *      This function is used to enable or disable some mail configuration fields.
-     * @param {Object} obj The form object that holds the value that makes fields visible or hidden
+     *      This function is used to enalbe or disable some mail configuration fields.
+     * @param {Object} obj The form object that has the value to decide if enable or disable fields
      * @return nothing
      */
     TargetNS.SelectOutboundMailType = function (obj) {
@@ -78,7 +80,7 @@ InstallerDBStart
     /**
      * @function
      * @return nothing
-     *      This function checks the SMTP configuration
+     *      This function check for the SMTP configuration
      */
     TargetNS.CheckSMTPAuth = function (obj) {
         if ($(obj).is(':checked')) {
@@ -93,7 +95,7 @@ InstallerDBStart
     /**
      * @function
      * @return nothing
-     *      This function skips the mail configuration
+     *      This function skip check the mail configuration
      */
     TargetNS.SkipMailConfig = function () {
         $('input[name=Skip]').val('1');
@@ -112,14 +114,14 @@ InstallerDBStart
         var Data = Core.AJAX.SerializeForm( $('#FormMail') );
         Data += 'CheckMode=Mail;';
         Core.AJAX.FunctionCall(Core.Config.Get('Baselink'), Data, CheckMailConfigCallback );
-        $('input[name=Subaction]').val('Registration');
+        $('input[name=Subaction]').val('Finish');
     };
 
     /**
      * @function
      * @private
      * @return nothing
-     * @description This function shows the mail configuration check result
+     * @description This function shows the check the mail configuration result
      */
     function CheckMailConfigCallback(json) {
         if (parseInt(json['Successful']) == 1) {
@@ -133,16 +135,5 @@ InstallerDBStart
             alert(Core.Config.Get('Installer.CheckMailLabelTwo'));
         }
     };
-    
-    /**
-     * @function
-     * @return nothing
-     *      This function skips the registration
-     */
-    TargetNS.SkipRegistration = function () {
-        $('input[name=Skip]').val('1');
-        $('form').submit();
-    };
-    
     return TargetNS;
-}(Core.Installer || {}));
+}(Core.Installer || {}));
\ No newline at end of file
